/**
 * @description tablecard setting表单配置信息
 */
export function getTableSetting (setting, columns, buttons = [], action = []) {
  let _columns = columns.map(item => ({value: item.field, label: item.label}))
  _columns.push({value: '$Index', label: '序号（前端）'})
  let appType = sessionStorage.getItem('appType')
  let menulist = []
  let appmenulist = []

  if (appType) {
    appmenulist = sessionStorage.getItem('appMenus')
    if (appmenulist) {
      try {
        appmenulist = JSON.parse(appmenulist)
      } catch (e) {
        appmenulist = []
      }
    } else {
      appmenulist = []
    }
  } else {
    menulist = sessionStorage.getItem('fstMenuList')
    if (menulist) {
      try {
        menulist = JSON.parse(menulist)
      } catch (e) {
        menulist = []
      }
    } else {
      menulist = []
    }
  }

  const settingForm = [
    {
      type: 'radio',
      field: 'condition',
      label: '显示条件',
      initval: setting.condition || 'false',
      tooltip: '当选择“有”时，只有符合条件的数据才会展示。',
      required: false,
      options: [
        {value: 'true', label: '有'},
        {value: 'false', label: '无'},
      ],
      controlFields: [
        {field: 'controlField', values: ['true']},
        {field: 'controlType', values: ['true']},
        {field: 'controlValue', values: ['true']},
      ]
    },
    {
      type: 'select',
      field: 'controlField',
      label: '控制字段',
      initval: setting.controlField || '',
      required: true,
      options: _columns
    },
    {
      type: 'radio',
      field: 'controlType',
      label: '对比方式',
      initval: setting.controlType || '=',
      required: true,
      options: [
        {value: '=', label: '='},
        {value: '!=', label: '!='},
        {value: '>', label: '>'},
        {value: '<', label: '<'},
      ]
    },
    {
      type: 'text',
      field: 'controlValue',
      label: '对比值',
      initval: setting.controlValue || '',
      required: false
    },
    {
      type: 'radio',
      field: 'click',
      label: '点击事件',
      initval: setting.click || '',
      tooltip: '当选择触发按钮时，只有当卡片中只存在一个按钮时有效。',
      required: false,
      options: [
        {value: '', label: '无'},
        {value: 'menu', label: '菜单'},
        {value: 'link', label: '链接'},
        {value: 'button', label: '按钮'},
      ],
      controlFields: [
        {field: 'menu', values: ['menu']},
        {field: 'linkurl', values: ['link']},
        {field: 'open', values: ['menu', 'link']},
        {field: 'joint', values: ['menu', 'link']},
        {field: 'linkbtn', values: ['button']},
      ]
    },
    {
      type: 'radio',
      field: 'joint',
      label: '参数拼接',
      initval: setting.joint || 'true',
      required: false,
      options: [
        {value: 'true', label: '是'},
        {value: 'false', label: '否'},
      ],
    },
    {
      type: 'radio',
      field: 'open',
      label: '打开方式',
      initval: setting.open || 'blank',
      required: false,
      options: [
        {value: 'blank', label: appType !== 'mob' ? '新窗口' : '新页面'},
        {value: 'self', label: appType !== 'mob' ? '当前窗口' : '当前页面'},
      ],
      forbid: appType !== 'pc' && appType !== 'mob'
    },
    {
      type: appType ? 'select' : 'cascader',
      field: 'menu',
      label: '关联菜单',
      initval: setting.menu || (appType ? '' : []),
      required: true,
      extendName: 'MenuNo',
      options: appType ? appmenulist : menulist,
    },
    {
      type: 'textarea',
      field: 'linkurl',
      label: '链接',
      initval: setting.linkurl || '',
      required: true,
      options: [],
      span: 24
    },
    {
      type: 'select',
      field: 'linkbtn',
      label: '关联按钮',
      initval: setting.linkbtn || '',
      required: true,
      options: buttons
    },
    {
      type: 'radio',
      field: 'swipe',
      label: '滑动按钮',
      initval: setting.swipe || 'true',
      required: false,
      options: [
        {value: 'true', label: '显示'},
        {value: 'false', label: '不显示'},
      ],
      forbid: action.length === 0 || appType !== 'mob'
    }
  ]

  return settingForm
}

/**
 * @description carousel setting表单配置信息
 */
export function getCarouselSetting (setting, hasPrimaryKey) {
  let appType = sessionStorage.getItem('appType')

  let menulist = []
  let appmenulist = []

  if (appType) {
    appmenulist = sessionStorage.getItem('appMenus')
    if (appmenulist) {
      try {
        appmenulist = JSON.parse(appmenulist)
      } catch (e) {
        appmenulist = []
      }
    } else {
      appmenulist = []
    }
  } else {
    menulist = sessionStorage.getItem('fstMenuList')
    if (menulist) {
      try {
        menulist = JSON.parse(menulist)
      } catch (e) {
        menulist = []
      }
    } else {
      menulist = []
    }
  }

  const cardSettingForm = [
    {
      type: 'text',
      field: 'primaryId',
      label: '主键值',
      initval: setting.primaryId || '',
      tooltip: '设置一个属性卡静态ID，向其他组件传递的指定静态ID值',
      required: false,
      forbid: !hasPrimaryKey
    },
    {
      type: 'radio',
      field: 'click',
      label: '点击事件',
      initval: setting.click || '',
      required: false,
      options: [
        {value: '', label: '无'},
        {value: 'menu', label: '菜单'},
        {value: 'link', label: '链接'},
      ],
      controlFields: [
        {field: 'menu', values: ['menu']},
        {field: 'linkurl', values: ['link']},
        {field: 'open', values: ['menu', 'link']},
        {field: 'joint', values: ['menu', 'link']},
      ]
    },
    {
      type: appType ? 'select' : 'cascader',
      field: 'menu',
      label: '关联菜单',
      initval: setting.menu || (appType ? '' : []),
      required: true,
      extendName: 'MenuNo',
      options: appType ? appmenulist : menulist,
    },
    {
      type: 'radio',
      field: 'open',
      label: '打开方式',
      initval: setting.open || 'blank',
      required: false,
      options: [
        {value: 'blank', label: appType !== 'mob' ? '新窗口' : '新页面'},
        {value: 'self', label: appType !== 'mob' ? '当前窗口' : '当前页面'},
      ],
      forbid: appType !== 'pc' && appType !== 'mob'
    },
    {
      type: 'radio',
      field: 'joint',
      label: '参数拼接',
      initval: setting.joint || 'true',
      required: false,
      options: [
        {value: 'true', label: '是'},
        {value: 'false', label: '否'},
      ],
    },
    {
      type: 'textarea',
      field: 'linkurl',
      label: '链接',
      initval: setting.linkurl || '',
      required: true,
      options: [],
      span: 24
    },
  ]

  return cardSettingForm
}